from sqlalchemy.orm.attributes import InstrumentedAttribute as InstrumentedAttribute
from sqlalchemy.orm.collections import InstrumentedList as InstrumentedList
from sqlalchemy.orm.query import Query as Query
from sqlalchemy.orm.session import Session
from sqlalchemy.sql.elements import BooleanClauseList as BooleanClauseList
from typing import Any, Callable, Dict, List, Optional, Union

class BaseNestedSets:
    @classmethod
    def __declare_first__(cls: Any) -> None: ...
    @classmethod
    def get_default_level(cls: Any) -> int: ...
    @classmethod
    def get_pk_name(cls: Any) -> str: ...
    @classmethod
    def get_pk_column(cls: Any) -> InstrumentedAttribute: ...
    def get_pk_value(self) -> int: ...
    def tree_id(self): ...
    def parent_id(self): ...
    def parent(self): ...
    def left(self): ...
    def right(self): ...
    def level(self): ...
    def is_ancestor_of(self, other: Any, inclusive: bool=...) -> bool: ...
    def is_descendant_of(self, other: Any, inclusive: bool=...) -> bool: ...
    mptt_move_inside: Any = ...
    def move_inside(self, parent_id: str) -> None: ...
    mptt_move_after: Any = ...
    def move_after(self, node_id: str) -> None: ...
    mptt_move_before: Any = ...
    def move_before(self, node_id: Union[int, str]) -> None: ...
    def leftsibling_in_level(self) -> Optional[Any]: ...
    @classmethod
    def get_tree(cls: Any, session: Session=..., json: bool=..., json_fields: Optional[Any]=..., query: Optional[Any]=...) -> List[Dict[str, Any]]: ...
    def drilldown_tree(self, session: Session=..., json: bool=..., json_fields: Optional[Any]=...) -> List[Dict[str, Any]]: ...
    def path_to_root(self, session: Session=..., order: Callable=...) -> Query: ...
    def get_siblings(self, include_self: bool=..., session: Optional[Session]=...) -> Query: ...
    def get_children(self, session: Optional[Session]=...) -> Query: ...
    @classmethod
    def rebuild_tree(cls: Any, session: Session, tree_id: Union[int, str]) -> None: ...
    @classmethod
    def rebuild(cls: Any, session: Session, tree_id: Optional[int]=...) -> None: ...



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['sqlalchemy_mptt-stubs']

package_data = \
{'': ['*']}

install_requires = \
['sqlalchemy-stubs>=0.3,<0.4', 'sqlalchemy_mptt>=0.2.5,<0.3.0']

setup_kwargs = {
    'name': 'sqlalchemy-mptt-stubs',
    'version': '0.0.3',
    'description': 'Stubs for sqlalchemy_mptt',
    'long_description': "sqlalchemy_mptt-stubs\n========================\n[![PyPI](https://img.shields.io/badge/pypi-0.0.3-orange.svg)](https://pypi.org/project/sqlalchemy-mptt-stubs/0.0.3) [![PyPI](https://img.shields.io/badge/python-3-blue.svg)](https://pypi.org/project/sqlalchemy-mptt-stubs/0.0.3)\n\nMost annotations generated by py pyannotate. It's still unstable.\n",
    'author': 'ssfdust',
    'author_email': 'ssfdust@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/ssfdust/sqlalchemy_mptt-stubs',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)



from __future__ import annotations
import weakref
from sqlalchemy.engine.base import Connection
from sqlalchemy.orm.mapper import Mapper
from sqlalchemy.orm.session import Session, sessionmaker
from sqlalchemy.orm.unitofwork import UOWTransaction
from sqlalchemy.sql.schema import Column, Table
from typing import Any, Union

def mptt_before_insert(mapper: Mapper, connection: Connection, instance: Any) -> None: ...
def mptt_before_delete(mapper: Mapper, connection: Connection, instance: Any, delete: bool=...) -> None: ...
def mptt_before_update(mapper: Mapper, connection: Connection, instance: Any) -> None: ...

class _WeakDictBasedSet(weakref.WeakKeyDictionary):
    def add(self, obj: Any) -> None: ...
    def discard(self, obj: Any) -> None: ...
    def pop(self) -> Any: ...

class _WeakDefaultDict(weakref.WeakKeyDictionary):
    def __getitem__(self, key: Session) -> _WeakDictBasedSet: ...

class TreesManager:
    base_class: Any = ...
    classes: Any = ...
    instances: Any = ...
    def __init__(self, base_class: Any) -> None: ...
    def register_events(self, remove: bool=...) -> TreesManager: ...
    def register_factory(self, sessionmaker: sessionmaker) -> sessionmaker: ...
    def before_insert(self, mapper: Mapper, connection: Connection, instance: Any) -> None: ...
    def before_update(self, mapper: Mapper, connection: Connection, instance: Any) -> None: ...
    def before_delete(self, mapper: Mapper, connection: Connection, instance: Any) -> None: ...
    def after_flush_postexec(self, session: Session, context: UOWTransaction) -> None: ...
    @staticmethod
    def get_parent_value(instance: Any) -> Any: ...
    @staticmethod
    def expire_session_for_children(session: Session, instance: Any) -> None: ...
